<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>AboutDialogPrivate</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="83"/>
        <source>Version: %1</source>
        <translation>Verze: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="99"/>
        <source>Advanced, easy-to-use, and fast desktop environment based on Qt technologies.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Pokročilé, snadno použitelné a svižné pracovní prostředí založené na technologiích Qt.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="101"/>
        <source>LXQt would not have been possible without the &lt;a %1&gt;Razor-qt&lt;/a&gt; project and its many contributors.</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>LXQt by nebylo možné bez &lt;a %1&gt;dřívějšího projektu Razor-qt&lt;/a&gt; a jeho mnoha přispěvatelů.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="103"/>
        <source>Copyright: © %1-%2 %3</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Autorská práva: © %1-%2 %3</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="105"/>
        <source>Homepage: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Domovská stránka: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="107"/>
        <source>Wiki: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Wiki: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="109"/>
        <source>Development: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Vývoj: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="111"/>
        <source>License: %1</source>
        <comment>About dialog, &apos;About&apos; tab text</comment>
        <translation>Licence: %1</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="121"/>
        <source>LXQt is developed by the &lt;a %1&gt;LXQt Team and contributors&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>LXQt je vyvíjeno &lt;a %1&gt;členy týmu stejnojmenného projektu a dalšími přispěvateli&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="123"/>
        <source>If you are interested in working with our development team, &lt;a %1&gt;join us&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Authors&apos; tab text</comment>
        <translation>Pokud chcete spolupracovat na vývoji, &lt;a %1&gt;přidejte se&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="140"/>
        <source>Special thanks to:</source>
        <comment>About dialog, &apos;Thanks&apos; tab text</comment>
        <translation>Zvláštní poděkování:</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.cpp" line="147"/>
        <source>LXQt is translated into many languages thanks to the work of the translation teams all over the world. Translations can be done in &lt;a %1&gt;LXQt-Weblate&lt;/a&gt;.</source>
        <comment>About dialog, &apos;Translations&apos; tab text</comment>
        <translation>LXQt je přeloženo do mnoha jazyků díky práci překladatelských týmů z celého světa. Překlady lze provádět na &lt;a %1&gt;LXQt-Weblate&lt;/a&gt;.</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="14"/>
        <source>About LXQt</source>
        <translation>O LXQt</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="66"/>
        <source>About</source>
        <comment>About dialog, Tab title </comment>
        <translation>O prostředí</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="83"/>
        <source>Authors</source>
        <comment>About dialog, Tab title</comment>
        <translation>Autoři</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="100"/>
        <source>Thanks</source>
        <comment>About dialog, Tab title</comment>
        <translation>Poděkování</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="117"/>
        <source>Translations</source>
        <comment>About dialog, Tab title</comment>
        <translation>Překlady</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="134"/>
        <source>Technical Info</source>
        <comment>About dialog, Tab title</comment>
        <translation>Technické údaje</translation>
    </message>
    <message>
        <location filename="../aboutdialog/lxqtaboutdialog.ui" line="165"/>
        <source>Copy to clipboard</source>
        <translation>Zkopírovat do schránky</translation>
    </message>
</context>
</TS>
